local tab = {}
tab.index = 300
tab.text = "Guild (Online)";
tab.value = "guild_online";

tab.columnSort = function (table, rowa, rowb, sortbycol)
	local asc = table.cols[sortbycol].sort == "asc"
	local ka = KeystoneRollCall.tableData[rowa][1]
	local kb = KeystoneRollCall.tableData[rowb][1]
	return KeystoneRollCall:CompareKeystones("name", asc, ka, kb);
end

tab.populate = function()
	local includeKeyless = KeystoneRollCall.db.global.guildOnlineTabShowKeyless
	
	for i = 1, GetNumGuildMembers() do
		local fullName, rank, rankIndex, level, class, zone, note, officernote, online, status, classFileName, achievementPoints, achievementRank, isMobile, canSoR, reputation = GetGuildRosterInfo(i)
		if online then
			local keystone = KeystoneRollCall:getKeystone(fullName)
			
			if includeKeyless or keystone and keystone.level and keystone.level > 0 then
			
				local nameParts =  {strsplit("-",fullName)};
				if not keystone then
					tinsert(KeystoneRollCall.tableData, {
						{['name'] =fullName,['class'] = class,dungeon = -1,level = -1, dummy = true},
						fullName,
						KeystoneRollCall:colorClass(nameParts[1],class),
						KeystoneRollCall:colorClass(class,class),
						"",
						"",
						""
					});
				else
					local bestLevelLine = ""
					if keystone.bestLevel and keystone.bestDungeon then
						bestLevelLine = "+" .. KeystoneRollCall:colorLevelDifficulty(keystone.bestLevel,keystone.bestLevel).." " .. C_ChallengeMode.GetMapInfo(keystone.bestDungeon)
					end

					tinsert(KeystoneRollCall.tableData, {
						keystone,
						fullName,
						KeystoneRollCall:colorClass(nameParts[1],class),
						KeystoneRollCall:colorClass(class,class),
						C_ChallengeMode.GetMapInfo(keystone.dungeon),
						keystone.level == 0 and "" or KeystoneRollCall:colorLevelDifficulty(keystone.level,keystone.level),
						bestLevelLine
					});
				end
			end
		end
	end
	
	KeystoneRollCall.scrollTable:SortData();
end

tab.setup = function(container)
	local cols = {{
			['name'] = '',
			['width'] = 1,
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "name",
			['align'] = 'LEFT'
		},{
			['name'] = '',
			['width'] = 1,
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "name",
			['align'] = 'LEFT'
		},{
			['name'] = 'Character',
			['width'] = 90,
			['align'] = 'LEFT', 
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "name",
		},{
			['name'] = 'Class',
			['width'] = 105,
			['align'] = 'LEFT', 
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "class",
		},{
			['name'] = 'Dungeon',
			['width'] = 170,
			['align'] = 'CENTER',
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "dungeon",
		},{
			['name'] = 'Level',
			['width'] = 50,
			['align'] = 'CENTER',
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "level",
		},{
			['name'] = "Best Run (This Week)",
			['field'] = "bestLevel",
			["comparesort"] = KeystoneRollCall.columnSort,
			['width'] = 210,
			['align'] = 'LEFT',
		}
	}
	
	KeystoneRollCall.tableData = {};
	KeystoneRollCall.dummyKeystones = {};
	KeystoneRollCall.scrollTable = KeystoneRollCall.ScrollingTable:CreateST(cols,24);
	KeystoneRollCall.scrollTable:SetData(KeystoneRollCall.tableData, true);

	KeystoneRollCall.scrollTable:RegisterEvents({
		['OnClick'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable, btn,...)
			if not KeystoneRollCall.tableData or not KeystoneRollCall.tableData[realrow] then
				return
			end
			if KeystoneRollCall.tableData[realrow][1].dummy then
				SendChatMessage("If you get the addon Keystone Roll-Call we can easily view each other's keystones, as well as keystones from across our guilds.","WHISPER",  "Common", KeystoneRollCall.tableData[realrow][1].name);
			elseif KeystoneRollCall.tableData[realrow][1] then
				local keystone = KeystoneRollCall.tableData[realrow][1];
				if btn == "RightButton" then
					if UnitExists("target") and GetUnitName("target", true) then
						SendChatMessage(KeystoneRollCall:keystoneToString(keystone),"WHISPER", "COMMON",  GetUnitName("target", true));
					end
				else
					SendChatMessage(KeystoneRollCall:keystoneToString(keystone),KeystoneRollCall:getGroupChatChannel() ,  "Common")
				end
			end
		end,	
		['OnDoubleClick'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable, btn,...)
			if KeystoneRollCall.tableData and KeystoneRollCall.tableData[realrow] and not KeystoneRollCall.tableData[realrow][1].dummy then
				SendChatMessage(KeystoneRollCall:keystoneToString(KeystoneRollCall.tableData[realrow][1]),"GUILD" ,  "Common")
			end
		end,	
		['OnEnter'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable,...)
			if not realrow or not KeystoneRollCall.tableData[realrow] then
				return
				
			end
			if KeystoneRollCall.tableData[realrow][1].dummy then
				KeystoneRollCall.frame:SetStatusText("Click: Suggest Addon")
			else
				KeystoneRollCall.frame:SetStatusText("Left Click: Send to Party   -   Double Click: Send to Guild   -   Right Click: Send to Target")
			end
		end,
		['OnLeave'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable,...)
			KeystoneRollCall.frame:SetStatusText("")
		end,
	});
	
	local tableWrapper = KeystoneRollCall.AceGUI:Create('lib-st'):WrapST(KeystoneRollCall.scrollTable);
	tableWrapper.head_offset = 15;
	container:AddChild(tableWrapper);
end

KeystoneRollCall.tabs[tab.value] = tab;